==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/libraries/razorqt/translations/librazorqt_da_DK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da_DK">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="14"/>
        <source>Add plugins</source>
        <translation>Tilføj plugins</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Søg:</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="52"/>
        <source>Add plugin</source>
        <translation>Tilføj plugin</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="59"/>
        <source>Close</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <location filename="../powermanager.cpp" line="96"/>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="103"/>
        <source>Suspend</source>
        <translation>Slumre</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="110"/>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="117"/>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="124"/>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="137"/>
        <source>Razor Session Suspend</source>
        <translation>Razor Session Slumre</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="138"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Vil du virkelig sætte din computer i slumretilstand?&lt;p&gt;Slumretilstand sætter computeren i energispare tilstand. Systemtilstanden mistes hvis strømmen forsvinder.</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="149"/>
        <source>Razor Session Hibernate</source>
        <translation>Razor Session Dvale</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="150"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Vil du virkelig sætte din computer i dvaletilstand?&lt;p&gt;Dvaletilstand sætter computeren i energispare tilstand. Systemtilstanden bibeholdes hvis strømmen forsvinder.</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="161"/>
        <source>Razor Session Reboot</source>
        <translation>Razor Session Genstart</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="162"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Vil du virkelig genstarte din computer? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="173"/>
        <source>Razor Session Shutdown</source>
        <translation>Razor Session Luk Ned</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="174"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Vil du virkelig slukke din computer? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="185"/>
        <source>Razor Session Logout</source>
        <translation>Razor Session Log Ud</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="186"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Vil du virkelig logge ud? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="197"/>
        <location filename="../powermanager.cpp" line="202"/>
        <source>Razor Power Manager Error</source>
        <translation>Razor Strømstyringsfejl</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="197"/>
        <source>Hibernate failed.</source>
        <translation>Dvaletilstand mislykkedes.</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="202"/>
        <source>Suspend failed.</source>
        <translation>Slumretilstand mislykkedes.</translation>
    </message>
</context>
<context>
    <name>RazorConfigDialog</name>
    <message>
        <location filename="../razorconfigdialog.ui" line="6"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
</context>
<context>
    <name>RazorShortcutButton</name>
    <message>
        <location filename="../razorshortcutbutton.cpp" line="49"/>
        <source>Clear</source>
        <translation>Rens</translation>
    </message>
    <message>
        <location filename="../razorshortcutbutton.cpp" line="199"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
</context>
<context>
    <name>ScreenSaver</name>
    <message>
        <location filename="../screensaver.cpp" line="49"/>
        <source>Lock Screen</source>
        <translation>Lås Skærm</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="68"/>
        <location filename="../screensaver.cpp" line="76"/>
        <location filename="../screensaver.cpp" line="84"/>
        <location filename="../screensaver.cpp" line="96"/>
        <location filename="../screensaver.cpp" line="104"/>
        <location filename="../screensaver.cpp" line="112"/>
        <location filename="../screensaver.cpp" line="121"/>
        <source>Screen Saver Activation Error</source>
        <translation>Fejl ved aktivering af pauseskærm</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="69"/>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation>Fejl ved start af screensaver. xdg-pauseskærm kan ikke starte på grund af nedbrud.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="77"/>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation>Fejl ved start af screensaver. xdg-pauseskærm er ikke korrekt installeret.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="85"/>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation>Fejl ved start af screensaver. xdg-pauseskærm kan ikke starte.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="97"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Fejl ved start af screensaver. Syntaksfejl i argumenter til xdg-pauseskærm.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="105"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Fejl ved start af screensaver. Sørg for at du har xscreensaver installeret og kørende.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="113"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Fejl ved start af screensaver. Handling &apos;aktivere&apos; mislykkedes. Sørg for at du har xscreensaver installeret og kørende.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="122"/>
        <source>An error occurred starting screensaver. Unkown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation>Fejl ved start af screensaver. Ukendt fejl - udokumenteret returværdi fra xdg-pauseskærm=%1.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../razoraboutdlg.ui" line="14"/>
        <source> About Razor</source>
        <translation> Om Razor-Qt</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/libraries/razorqt/translations/librazorqt_da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation>Tilføj plugins</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Søg:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation>Tilføj plugin</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Slumre</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Razor Session Suspend</source>
        <translation>Razor Session Slumre</translation>
    </message>
    <message>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Vil du virkelig sætte din computer i slumretilstand?&lt;p&gt;Slumretilstand sætter computeren i energispare tilstand. Systemtilstanden mistes hvis strømmen forsvinder.</translation>
    </message>
    <message>
        <source>Razor Session Hibernate</source>
        <translation>Razor Session Dvale</translation>
    </message>
    <message>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Vil du virkelig sætte din computer i dvaletilstand?&lt;p&gt;Dvaletilstand sætter computeren i energispare tilstand. Systemtilstanden bibeholdes hvis strømmen forsvinder.</translation>
    </message>
    <message>
        <source>Razor Session Reboot</source>
        <translation>Razor Session Genstart</translation>
    </message>
    <message>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Vil du virkelig genstarte din computer? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <source>Razor Session Shutdown</source>
        <translation>Razor Session Luk Ned</translation>
    </message>
    <message>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Vil du virkelig slukke din computer? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <source>Razor Session Logout</source>
        <translation>Razor Session Log Ud</translation>
    </message>
    <message>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Vil du virkelig logge ud? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <source>Razor Power Manager Error</source>
        <translation>Razor Strømstyringsfejl</translation>
    </message>
    <message>
        <source>Hibernate failed.</source>
        <translation>Dvaletilstand mislykkedes.</translation>
    </message>
    <message>
        <source>Suspend failed.</source>
        <translation>Slumretilstand mislykkedes.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Power Manager Error</source>
        <translation>Strømstyrings fejl</translation>
    </message>
    <message>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface er ugyldig</translation>
    </message>
    <message>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Strømstyrings fejl (D-BUS kald)</translation>
    </message>
</context>
<context>
    <name>RazorAboutDLGPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <translation>Avanceret, nem at bruge, hurtigt skrivebordsmiljø baseret på Qt teknologier.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Copyright: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Hjemmeside: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Licens: %1</translation>
    </message>
    <message>
        <source>Razor-qt is developed by the &lt;a %1&gt;Razor-qt Team and contributors&lt;/a&gt; on Github.</source>
        <translation>Razor-Qt er udviklet af &lt;a %1&gt; Razor-Qt holdet og bidragydere &lt;/ a&gt; på Github.</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Hvis du er interesseret i at arbejde sammen med os, &lt;a %1&gt; slut dig til os &lt;/ a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>En særlig tak til:</translation>
    </message>
    <message>
        <source>Razor-qt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <translation>Razor-Qt er oversat til mange sprog takket være oversættere fra hele verden.</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <source>&lt;b&gt;Razor Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation>&lt;b&gt;Razor Desktop Værktøjskasse - Teknisk Information&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation>Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation>Fejlsøgningsversion</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation>Systemindstillinger</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation>Delt Katalog</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Oversættelser</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation>&lt;b&gt;Bruger Biblioteker&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation>Xdg Brugerdata Katalog</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation>Xdg Konfigurationsdata Katalog</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation>Xdg Data Kataloger</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation>Xdg Cache Katalog</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation>Xdg udførselskatalog</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation>Xdg Autostart Katalog</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation>Xdg Autostart Hjemmekatalog</translation>
    </message>
</context>
<context>
    <name>RazorConfigDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
</context>
<context>
    <name>RazorNotificationPrivate</name>
    <message>
        <source>Notifications Fallback</source>
        <translation>Alternativ Påmindelse</translation>
    </message>
</context>
<context>
    <name>RazorShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation>Rens</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
</context>
<context>
    <name>ScreenSaver</name>
    <message>
        <source>Lock Screen</source>
        <translation>Lås Skærm</translation>
    </message>
    <message>
        <source>Screen Saver Activation Error</source>
        <translation>Fejl ved aktivering af pauseskærm</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation>Fejl ved start af screensaver. xdg-pauseskærm kan ikke starte på grund af nedbrud.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation>Fejl ved start af screensaver. xdg-pauseskærm er ikke korrekt installeret.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation>Fejl ved start af screensaver. xdg-pauseskærm kan ikke starte.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Fejl ved start af screensaver. Syntaksfejl i argumenter til xdg-pauseskærm.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Fejl ved start af screensaver. Sørg for at du har xscreensaver installeret og kørende.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Fejl ved start af screensaver. Handling &apos;aktivere&apos; mislykkedes. Sørg for at du har xscreensaver installeret og kørende.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation>En fejl opstod ved start af pauseskærm. Ukendt fejl - udokumenteret returværdi sendt fra xdg-screensaver=%1.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About Razor</source>
        <translation> Om Razor-Qt</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Omkring</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Forfattere</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Oversættelser</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <translation>Teknisk Information</translation>
    </message>
</context>
</TS>
